"""
Plugin used to connect the tool to Github.

Will offer the user to open the url: https://git.sourceai.io/settings/tokens
to create a new token.

The toolbox will check if the user has a valid ssh key and ask the
user to generate one if missing

The users must give all permissions except:

- admin:gpg_key

"""

import click
from termcolor import cprint

from gamma.services.github import GitHubService


@click.command()
@click.pass_obj
def cli(telemetry):
    """ Allows connection with Github """

    if telemetry is not None:
        telemetry.track_event("login cmd")

    git = GitHubService()
    token = git.get_token()
    client = git.get_github_client(token)
    try:
        user = client.get_user()
        cprint("You have successfully logged in with the username: " + user.login, "green")
        keys = user.get_keys()
        number_of_key = 0
        for _ in keys:
            number_of_key += 1
        if number_of_key > 0:
            cprint("You also have a valid ssh key", "green")
        else:
            cprint(
                "You should generate a ssh key and add it to your account. "
                "Please visit (https://git.sourceai.io/settings/keys) to generate a key",
                "yellow",
            )

        if telemetry is not None:
            telemetry.track_event("github login OK")
            telemetry.flush()
    except:
        git.delete_token_file()
        print("Invalid or expired token, please try the login command again")
        if telemetry is not None:
            telemetry.track_event("github login not OK")
            telemetry.flush()
