"""
Gamma toolbox helping to bootstrap new projects and all the common operations
needed along the lifecycle of projects
"""

import os
import sys

import click

PACKAGE_PATH = os.path.dirname(os.path.abspath(__file__))
sys.path.insert(0, PACKAGE_PATH + "/..")

# pylint: disable=wrong-import-position
from gamma.monitoring import enable_monitoring
from gamma.updater import check_version

PLUGIN_FOLDER = os.path.join(os.path.dirname(__file__), "commands")


class CLI(click.MultiCommand):
    """
    Define the CLI commands by lookup inside the ./commands directory
    """

    def list_commands(self, ctx):
        plugins = []
        for filename in os.listdir(PLUGIN_FOLDER):
            if filename.endswith(".py") and filename != "__init__.py":
                plugins.append(filename[:-3])
        plugins.sort()
        return plugins

    def get_command(self, ctx, cmd_name):
        commands = {}
        filename = os.path.join(PLUGIN_FOLDER, cmd_name + ".py")
        with open(filename) as file:
            code = compile(file.read(), filename, "exec")
            eval(code, commands, commands)
        return commands["cli"]


@click.version_option()
@click.command(cls=CLI)
@click.pass_context
@click.option("--no-telemetry", envvar="NO_TELEMETRY", is_flag=True)
def cli(ctx, no_telemetry):
    """
    Gamma Toolbox
    """

    ctx.obj = enable_monitoring(no_telemetry)
    check_version()


if __name__ == "__main__":
    # pylint: disable=no-value-for-parameter
    cli()
