"""
Pushing all the exceptions to sentry.io to be alerted and be able to prepare a new version
"""

import os

import sentry_sdk
from applicationinsights import TelemetryClient

from gamma.metadata import __version__


def enable_monitoring(disable_telemetry: bool, init_event=True):
    """
    Enable the monitoring to catch all the exception and be alerted.

    You can disable the monitoring by setting:

    - the evar NO_TELEMETRY=0
    - the option --no-telemetry when using the tool

    """

    if not disable_telemetry:
        sentry_sdk.init(
            "https://399c99d43c9c485085d4ea88ca095b41@sentry.io/1515986",
            release=__version__,
        )

        telemetry = TelemetryClient("bd10c324-3a15-4eed-b6c1-3db06a38eaaf")
        telemetry.context.application.ver = __version__
        telemetry.context.user.id = os.getenv("USER", "anonymous")
        if init_event is True:
            telemetry.track_event("init")

        return telemetry

    return None
